//TX67819  JOB  (1),TX67819,
//             CLASS=A,MSGCLASS=A,MSGLEVEL=(1,1),COND=(0,NE)
//*
//* 2022/04/23 @kl TX67819 Add TYPRUN=SCAN text to message IEF452I
//*                        if appropriate.
//*
//RECEIVE EXEC SMP4
//SMPPTFIN DD DATA,DLM='??'
++ USERMOD(TX67819)     /* REWORK(20220423) */             .
++ VER (X067)
   FMID(EBA1101)
 /*
   PROBLEM DESCRIPTION(S):
     TX67819 -
       Change text of message IEF452I JOB NOT RUN to specify
       reason as either JCL ERROR or TYPRUN=SCAN as appropriate,
       consistent with VS1 release 7.0.

   COMPONENT:  5741-SC1B4-EBA1101
               5741-SC1B9-EBA1101

   APARS FIXED:  TX67819

   SPECIAL CONDITIONS:
     DOCUMENTATION:  Explanation of message IEF452I replaced.

       Publication:  OS/VS1 System Messages
       Form Number:  GC38-1001

       IEF452I xxx JOB NOT RUN - { JCL ERROR | TYPRUN=SCAN }
               [TIME=hh.mm.ss]

       Explanation:  If xxx is a job name, the interpreter detected an
       error in a job control statement, the job was canceled while on
       the input queue, or TYPRUN=SCAN was specified on the JOB card.

       If xxx is a cataloged procedure name, the procedure was
       specified in the first operand of a START command. In this
       case, either the procedure was not found in the system
       procedure library (SYSl.PROCLIB) or, if found, the procedure
       had an error in a job control statement.

       The actual error message appears in the system output (SYSOUT)
       data set.

       In response to a MONITOR command with JOBNAMES,T in its operand
       field, this message also indicates the time of day, where hh
       specifies the hour (00-23), mm specifies the minute (00-59),
       and ss specifies the second (00-59).

       System Action:  If xxx is a job name, the job was not initiated
       and no steps were executed. If xxx is a procedure name, the
       START command was not executed.

       Operator Response:  If xxx is a job name, none. If xxx is a
       procedure name, either reenter the START command with the
       correct procedure name, or, if the procedure name is correct,
       have the programmer responsible for the system check the
       procedure for errors.

   COMMENTS:
     LAST CHANGE:  2022/04/23

    THE FOLLOWING MODULES AND/OR MACROS ARE AFFECTED BY THIS USERMOD:

    MODULES
      IEFSD21Q
      IEFVGK
      IEFWSTRT

    LISTEND
 */.
++ ZAP      (IEFVGK  ) DISTLIB(AOSB3   ).
NAME IEFIRC IEFVGK
IDRDATA TX67819
* (VER) SSS 34,SCAN
VER 020F 34        DC  XL1'34'                NBR CNTRL/COMPARE BYTES
VER 0210 E2C3C1D5  DC  C'SCAN'                COMPARE PATTERN
* (VER) BBC 01,JCTJSTAT-INJMJCT,INCMSTS
VER 0214 01        DC  XL1'01'                FUNCT/TABLE
VER 0215 05        DC  AL1(JCTJSTAT-INJMJCT)  OFFSET IN TABLE
VER 0216 04        DC  AL1(INCMSTS)           BIT PATTERN
* (REP) BBC 01,JCTJSTAT-INJMJCT,JCTJFLSH
REP 0214 01        DC  XL1'01'                FUNCT/TABLE
REP 0215 05        DC  AL1(JCTJSTAT-INJMJCT)  OFFSET IN TABLE
REP 0216 40        DC  AL1(JCTJFLSH)          BIT PATTERN
++ SRC      (IEFSD21Q) DISTLIB(ASAMPLIB) SYSLIB(SAMPLIB ).
         PRINT OFF
         MACRO                                                          01200001
         IEFQMNGR  &TYPE=DSECT                                          02000001
.*MODULE NAME = IEFQMNGR(OS/VS1)                               @X048E82 02050004
.*                                                                    * 02100004
.*DESCRIPTIVE NAME=  SWADS MANAGER PARM AREA                   @X048E82 02150004
.*                                                                    * 02200004
.*COPYRIGHT = NONE                                             @X048E82 02250004
.*                                                                    * 02300004
.*CHANGE ACTIVITY =                                            @X048E82 02350004
.*                                                                    * 02400004
         AIF   ('&TYPE' NE 'DSECT').DS0D WAS DEFAULT OVERRIDDEN         03000001
IOPARAMS DSECT                                                          04000001
         AGO   .CONTIN                                                  05000001
.DS0D    ANOP                                                           06000001
IOPARAMS DS    0D                                                       07000001
.CONTIN  ANOP                                                           08000001
         SPACE 2                                                        09000001
***************************************                                 10000001
*                                     *      THIS MAPPING MAY BE        11000001
* SWADS MANAGER PARAMETER AREA        *      ASSEMBLED INLINE BY        12000004
*                                     *      OVERRIDING TYPE=DSECT      13000001
***************************************                                 14000001
         SPACE 2                                                        15000001
**                                                                      15200002
*        OS/VS1    RELEASE 3     LEVEL 1     4/25/72                    15400003
**                                                                      15600002
.*                                     KEYWORD PARAMETER ADDED TO       16000001
.*                                     ENABLE INCLUSION OF THIS         17000001
.*                                     MAPPING WITHIN ANOTHER DSECT     18000001
QMNAM    DS    CL8                     JOB NAME                 XL03120 19000003
QMPOP    DS    CL1                           FUNCTION CODE PARAMETER    22000001
*                   FUNCTION CODE VALUES                                23000001
QMASGS   EQU   X'00'                    ASSIGN/START WITH ASSIGN        23050003
QMASGN   EQU   X'01'                         ASSIGN                     24000003
QMWRTA   EQU   X'02'                         WRITE AND ASSIGN           26000003
QMWRTE   EQU   X'03'                         WRITE                      27000003
QMREAD   EQU   X'04'                         READ                       28000003
QMDELE   EQU   X'08'                         DELETE                     32000003
QMDELN   EQU   X'18'                   DEL, NO FREEMAIN OF ECB   X02050 32100002
QMSTRT   EQU   X'09'                    ASSIGN/START - NO ASSIGN        32200003
QMWRTV   EQU   X'0A'                    WRITE - VARIABLE LENGTH REC     32400003
QMREDV   EQU   X'0B'                    READ - VARIABLE LENGTH REC      32600003
QMFLT    DS    CL2                           1ST LGCL TRK ASGND TO JOB  34000001
QMTST    DS    CL1                           NO. RCRDS USED IN LOG. TRK 35000001
QMTLN    DS    CL2                           REL. ADDR OF NEXT LOG. TRK 36000001
QMNOT    DS    CL1                           NO. LOG TRKS ASGND TO JOB  37000001
QMEXCPVR DS    CL1                     EXCPVR PROCESSING SW    @X31EV82 37100004
QMSTA    DS    CL1                     SWADS FLAG BITS          XL03120 37150003
*                                      OR SWA FLAG BITS         XL03051 37160003
QMIRCR   EQU   X'20'                   SPECIAL RTN CODE REQUEST XL03120 37200003
*                                      FROM INTERPRETER         XL03120 37250003
QMSTDS   EQU   X'40'                   SCHEDULER TABLE DATA             42000003
*                                      INDICATOR                        43000001
QMRBS    EQU   X'80'                   MSG INIDICATOR           XL03936 43050003
QMPRI    DS    CL1                           JOB PRIORITY               44000001
*                                      BIT 2 = 0 - INTERPRETER REQUEST  44010003
*                                      BIT 2 = 1 - INITIATOR REQUEST    44020003
QMQID    DS    CL2                     QID                      XL03120 44050003
QMTID    DS    CL2                           Q ENTRY IDENTIFICATION     46000001
QMLNK    DS    CL2                    NEXT SWADS ENTRY TO ASSGN XL03120 47000003
*                                     OR NXT SWA ENTRY TO ASSGN XL03051 47050003
QMWTQ    DS    CL4                     PTR TO SWADS DCB         XL03120 48000003
*                                      OR SWA BLK               XL03051 48050003
QMEIA    DS    CL4                                ADDR USERS ECB/IOB LC 49000001
QMPCM    DS    0X                      NO RECS TO ASSIGN (BITS 0-3)     50000001
QMPNC    DS    0X                      NO RECS TO READ WRITE (BITS 4-7) 51000001
QMPCL    DS    A                       ADDR OF EXTERNAL PARM AREA       52000001
         MEND                                                           53000001
         PRINT ON
         TITLE      'IEFSD21Q - VMS ALLOCATION ENTRY INTERFACE'         00020000
*********************************************************************** 00040000
*                                                                     * 00060000
*   MODULE-NAME =    IEFSD21Q (VS/1)                           @X048E75 00080004
*                                                                     * 00100000
*   DESCRIPTIVE-NAME = IEFSD21Q - VMS ALLOC ENTRY INTERFACE    @X048E75 00110004
*                                                              @X048E75 00112004
*   COPYRIGHT = NONE                                           @X048E75 00114004
*                                                              @X048E75 00116004
*   STATUS:         RELEASE 6.7 WITH USERMOD TX67819           @TX67819 00120007
*                                                                     * 00140000
*   FUNCTION:       PROVIDE AN INTERFACE FOR AN ENTRY TO ALLOCATE IN  * 00160000
*                   A VMS ENVIRONMENT                                 * 00180000
*                                                                     * 00200000
*   ENTRY POINT:    IEFW21SD                                          * 00220000
*                                                                     * 00240000
*   INPUT:       1. REGISTER 1 POINTING TO A PARAMETER AREA CONTAINING* 00260000
*                        A. CORE ADDRESS OF JCT                       * 00280000
*                        B. CORE ADDRESS OF LCT                       * 00300000
*                        C.  4  WORDS OF ZEROS                        * 00320000
*                2. THE LCT INITIALIZED TO CONTAIN THE FOLLOWING:     * 00340000
*                        A. LCTCMCBA WILL POINT TO A TWO-LEVEL        * 00360000
*                           REGISTER SAVE AREA AND THE QMGR PARAMETER * 00380000
*                           AREA (180 BYTES).                         * 00400000
*                        B. LCTPSPAR WILL CONTAIN THE ADDRESS OF THE  * 00420000
*                           RESIDENT BLOCK OF CORE CONTAINING         * 00440000
*                             1) A WORD OF ZEROS RESERVED             * 00460000
*                             2) A WORD OF ZEROS RESERVED             * 00480000
*                            3) AN ECB ON WHICH ALLOCATE WILL WAIT    * 00500000
*                               AND TERMINATE WILL POST               * 00520000
*                            4) A 4-BYTE SLOT USED BY ALLOCATE AND    * 00540000
*                               IEFDPOST FOR COMMUNICATION PURPOSES   * 00560000
*                        C. LCTQDRTY WILL CONTAIN THE ADDRESS OF THE  * 00580000
*                           CSCB(COMMAND SCHEDULING CONTROL BLOCK).   * 00600000
*                        D. LCTSRTAD WILL CONTAIN THE ADDRESS OF THE  * 00620000
*                           UCB LIST.                                 * 00640000
*                        E. LCTACTON WILL CONTAIN THE EBCDIC CHARACTER* 00660000
*                           'A'. THIS IS THE ACTION CODE INDICATING A * 00680000
*                           NORMAL ENTRY TO ALLOCATE.                 * 00700000
*                                            CODES DWB 11.94.41-40    * 00720000
*                        F. LCTQENTY WILL BE THE EMPTY SLOT USED BY   * 00740000
*                           ALLOCATE ENTRY AND EXIT TO STORE THE      * 00760000
*                           ADDRESS OF THE LINKOR'S REGISTER SAVE     * 00780000
*                           AREA.                                     * 00800000
*                        G. LCTSCTAD WILL CONTAIN THE CORE ADDRESS    * 00820000
*                           OF THE SCT FOR THE STEP TO BE ALLOCATED   * 00840000
*                        H. LCTSNUMB WILL CONTAIN THE STEP NO.        * 00860000
*                                                                     * 00880000
*   OUTPUT:           1. LCT                                          * 00900000
*                                                                     * 00920000
*   EXTERNAL ROUTINES:                                                * 00940000
*                     1. VMS QUEUE MANAGER                            * 00960000
*                                                                     * 00980000
*   EXITS:    NORMAL  1. CONDITION CODE PROCESSING - IEFVK            * 01000000
*             ERROR  2.  ALLOCATE FLUSH - IEFVM(JFCB HSKP)           V* 01020000
*                                                                     * 01060000
*   TABLES/WORKAREAS                                                  * 01080000
*                     JCT,LCT,SCT,SMB,QUEUE MANAGER PARAMETER AREA,   * 01100000
*                     QCB,QEL,CVT                                     * 01120000
*                                                                     * 01140000
*   ATTRIBUTES:       READ ONLY AND REENTRANT                         * 01160000
*                                                                     * 01180000
*********************************************************************** 01200000
* KMSA CORRESPONDS TO INC. IMPROVEMENT 152, DISPLAY JOBNAMES,T          01210016
         EJECT                                                          01220000
*                                            SYMBOLIC REGISTER NAMES    01240000
IEFW21SD CSECT                                                   A24159 01250018
*A015700,020086-020092,020110                                    X02045 01251002
*A015780-015860,022880-023380,025470,025770-025890,026602-026652 X02050 01252002
*A036620-036720,036800-038200,039500-039550,039600-039780,042525 X02050 01253002
*A042930,043410,052173-052193                                    X02050 01254002
*D022880-023500,025470-025560,052173-052197                      X02050 01255002
R0       EQU   0                                                        01260000
R1       EQU   1                                                        01280000
R2       EQU   2                                                        01300000
R3       EQU   3                                                        01320000
R4       EQU   4                                                        01340000
R5       EQU   5                                                        01360000
R6       EQU   6                                                        01380000
R7       EQU   7                                                        01400000
R8       EQU   8                                                        01420000
R9       EQU   9                                                        01440000
R10      EQU   10                                                       01460000
R11      EQU   11                                                       01480000
R12      EQU   12                                                       01500000
R13      EQU   13                                                       01520000
R14      EQU   14                                                       01540000
R15      EQU   15                                                       01560000
PPGM     EQU   X'C0'                                                    01565001
SHORTLN1 EQU   28                      LENGTH OF JOB STARTED MSG X02050 01578002
SHORTLN2 EQU   42                      INTERMEDIATE MSG LENGTH   X02050 01579003
D7       EQU   7                       DISPLACEMENT VALUE        X02050 01580003
D8       EQU   8                       DISPLACEMENT VALUE        X02050 01581003
D22      EQU   22                      DISPLACEMENT VALUE        X02050 01582003
SHORTLEN EQU   46                      JOB FAILED MSG LENGTH   @TX67819 01586007
LONGLEN  EQU   X'3C'                   JOB FAILED MSG LENGTH   @TX67819 01590007
         SPACE 2                                                        01595801
*********************************************************************** 01596601
*  SET UP USING & STORE REG SAVE PTR & JCT INTO LCT                   * 01597401
*********************************************************************** 01598201
         SAVE  (0,12),T                      SAVE USERS REGISTERS       01600000
         BALR  R9,R0                         SET BASE REGISTER FOR      01620000
         USING *,R9                               THIS ROUTINE          01640000
         B     FIRST                                                    01660000
         DC    CL8'IEFSD21Q'                 MODULE NAME                01700000
         DC    X'20220423'             DATE OF UPDATE          @TX67819 01720007
FIRST    DS    0H                                                       01760000
         L     R12,0(R1)                     SET BASE OF LCT            01780000
         USING LCT,R12                                                  01800000
         XC    LCTERROR(4),LCTERROR    CLEAR LCT ERROR FIELD   @XA10790 01805006
         IC    R6,LCTQENTY              SAVE SWITCHES                   01810015
         ST    R13,LCTQENTY             SAVE REG SAVE PTR               01820015
         STC   R6,LCTQENTY              RESTORE SWITCHES                01830015
         NI    LCTQENTY,X'01'           RESET ALL BUT ERROR SWITCH      01840015
         MVC   LCTJCTAD(4),4(R1)             MOVE JCT ADDR INTO LCT     01860000
         L     R4,VMADC18              LOAD ADDR. OF SWDS FULL IND.     01870001
         MVI   0(R4),X'00'             INIT. IND. TO X'00' FOR VMLS1    01880001
*                                       PARAMETER LIST                  01881002
         L     R5,LCTTCBAD        GET JOB/STEP TCB               A40791 01882002
         USING TCB,R5                                             M0726 01883002
         L     R5,TCBTCT          GET TCT ADDRESS                 M0726 01884002
         LTR   R5,R5              TEST FOR TCT(R5=0 = NO TCT)    A40791 01885002
         DROP  R5                                                 M0726 01886002
         BZ    IEFV21G0           NO TCT, SKIP SMP PROCESSING  @TX67819 01887007
         USING SMFTCT,R5                                         A40791 01888002
         TIME  BIN                ISSUE TIME MACRO FOR SMF       A40791 01889002
         ST    R0,TCTAST          STORE TIME IN TCT              A40791 01890002
         DROP  R5                                                       01891002
         TITLE  'IEFSD21Q CHECK FOR FIRST STEP && IF JOB FAILED '       02017001
*********************************************************************** 02037001
* SET R3 POINTING TO QID ENTRY FOR LATER TESTS FOR MONITOR JOBNMSX02050 02047002
* TEST FOR FIRST STEP, JOB FAILED BY INTERPR, &MESSAGE WRITTEN        * 02057001
*********************************************************************** 02077001
IEFV21G0 DS    0H                                              @TX67819 02077507
         L     R5,16                   ESTABLISH                 X02050 02078002
         USING CVT,R5                    CVT ADDRESSABILITY      X02050 02079002
         L     R5,CVTEXT2              ESTABLISH CVT EXTENSION   X02050 02080002
         USING CVTXTNT2,R5               ADDRESSABILITY          X02050 02081002
         L     R5,CVTQID               ESTABLISH ADDRESSABILITY  X02050 02082002
         LA    R5,0(R5)                  TI QID TABLE            X02050 02083002
         USING QIDPRE,R5                   PREFIX                X02050 02084002
         L     R3,LCTQDRTY             ESTABLISH ADDRESSABILITY  X02050 02085002
         USING CSCB,R3                   TO CSCB                 X02050 02086002
         LH    R3,CHQID                GET QID                   X02050 02087002
         STH   R3,JOBSQID              SAVE QID                  X02050 02088002
         MH    R3,QIDLNGTH             MULTIPLY QID ENTRY NUM BY ENTRY *02089002
                                       LENGTH TO GET DISPLACEMENT IN\O *02090002
                                       QID TABLE                 X02050 02091002
         A     R3,QIDTPTR              ADD DISPLACEMENT TO START ADDR  *02092002
                                       TO PT TO PROPER ENTRY     X02050 02093002
         DROP  R5                      RELEASE QID PREFIX PTR    X02050 02094002
         USING QID,R3                  QID TABLE ADDRESSABILITY  X02050 02095002
         SPACE 3                                                        02096002
         L     R4,LCTJCTAD                   LOAD JCT ADDR FROM LCT     02100000
         USING JCT,R4                                                   02120000
         L     R8,LCTSCTAD         LOAD ADDRESS OF SCT             CR17 02186017
         USING SCT,R8                                              CR17 02192017
         CLI   LCTSNUMB,X'01'                TEST FOR 1ST STEP IN JOB   02200000
         BNE   IEFV21G                  NO,BRANCH                       02210001
*                                       TO OPEN SPOOL MANAGEMENT    JES 02220001
*                                       DATA SET                    JES 02230001
IEFV21G2 EQU   *                                                   CR17 02244018
         TM    JCTJSTAT,INCMSTS+JCTJFLSH INTERP FAIL JOB?      @TX67819 02248007
         BZ    IEFV21G1                 NO,SEE IF JOBNAME IS TO BE    * 02249001
*                                       DISPLAYED                       02250001
         TM    LCTQENTY,LCTERRM   TEST IF TERM MESSAGE WRITTEN     4601 02252018
         BO    IEFV21G                  YES,ISSUE SMODS MACRO           02254001
         L     R5,LCTQDRTY             OBTAIN CSCB PTR                  02254101
         USING CSCB,R5                                                  02254201
         TM    CHSPA,PPGM              IS IT STARTED P/P                02254301
         DROP  R5                                                       02254401
         BO    IEF102ER                IF SO DONT ISSUE MSG.            02254501
         TITLE  'IEFSD21Q-WTO JOBNAME JOB NOT RUN-JCL ERROR'            02255001
*********************************************************************** 02256001
* WTO-JOB NOT RUN MESSAGE, IF JOB FAILED BY INTERPRETER AND    @TX67819 02257007
* TERMINATING MESSAGE WAS NOT WRITTEN  OR IF TYPRUN=SCAN JOB   @TX67819 02257607
*********************************************************************** 02259001
         GETMAIN R,LV=LN2,SP=240       GET AREA FOR MSG COPY        MCS 02262001
         L     R2,WTOAD                ADDR. OF MSG CSECT         KMSA  02266018
         MVC   0(LN2,R1),0(R2)         SET UP MSG COPY              MCS 02268018
         L     R5,16                   ESTABLISH ADDRESSABILITY    KMSA 02270018
         USING CVT,R5                  TO THE CVT AND             KMSA  02272018
         L     R5,CVTMSER               TO THE BASE                     02274001
         LR    R2,R1                    SAVE GETMAIN @                  02276001
         USING BASE,R5                                             KMSA 02278018
         TM    MSBTN,MSTN              IS TIME NOTE WANTED ?       KMSA 02280018
         DROP  R5                                                  KMSA 02282018
         BZ    IEF21G1A                NO                         KMSA  02284018
         BAL   R14,IEF21S1             YES. GO PUT TIME ON MSG   X02050 02288002
         B     IEF21G1B                GO ISSUE WTO              X02050 02290002
IEF21G1A EQU   *                                                 X02050 02292002
         USING WTERM040,R1             MSG ADDRESSABILITY        X02050 02294002
         MVI   LENGTH2,SHORTLEN        SHORT MSG LENGTH          X02050 02296002
         MVC   TIME2(8),CODES2         ADJUST MSG FOR NO TIME    X02050 02298002
IEF21G1B EQU   *                                                 X02050 02300002
         MVC   JOBNAME2(8),JCTJNAME    PUT JOB NAME IN MSG       X02050 02302002
         TM    JCTJSTAT,JCTJFLSH       TYPRUN=SCAN?            @TX67819 02302407
         BZ    JCLERR1                 NO. MSG TEXT IS OK      @TX67819 02302707
         MVC   REASON(L'SCANRUN),SCANRUN YES, MODIFY MSG TEXT  @TX67819 02303007
JCLERR1  DS    0H                                              @TX67819 02303307
         WTO   MF=(E,(1))              WRITE JOB FAILED MSG      X02050 02304002
         LH    R11,JOBSQID             IS THERE A                X02050 02306002
         LTR   R11,R11                   REMOTE USER             X02050 02308002
         BZ    IEF21G1F                NO. GO FREE CORE          X02050 02310002
         LR    R1,R2                   ADDR OF MSG TEXT          X02050 02312002
         STH   R11,QID2                PUT QID IN MSG             M8616 02313002
         TM    QIDIND4,QIDMJOBT        TIME NOTE WANTED?         X02050 02314002
         BZ    IEF21G1C                NO. GO ISSUE WTO          X02050 02316002
         BAL   R14,IEF21S1             YES. GO PUT TIME IN MSG   X02050 02318002
         B     IEF21G1D                GO ISSUE WTO              X02050 02320002
IEF21G1C EQU   *                                                 X02050 02322002
         MVI   LENGTH2,SHORTLEN        RESET MSG LENGTH          X02050 02324002
         MVC   TIME2(8),CODES2         ADJUST MSG FOR NO TIME    X02050 02326002
IEF21G1D EQU   *                                                 X02050 02328002
         MVC   JOBNAME2(8),JCTJNAME    PUT JOB NAME IN MSG       X02050 02330002
         WTO   MF=(E,(1))              WRITE JOB FAILED MSG TOREMOTE   *02334002
                                       TERMINAL                  X02050 02336002
IEF21G1F FREEMAIN R,LV=LN2,A=(R2),SP=240 FREE MSG AREA           X02050 02338002
IEF102ER OI    LCTQENTY,LCTERRM        TURN ON TERM MSG WRITTEN BI CR17 02351517
         B     IEFV21G                  BRANCH TO ISSUE SMODS MACRO JES 02351701
         TITLE  'IEFSD21Q WTO JOBNAME STARTED'                          02351901
*********************************************************************** 02352101
*  IF DISPLAY JOBNAMES FLAG IS ON WTO 'JOBNAME STARTED'               * 02352301
*  IF NOT,GO AND ISSUE SMODS MACRO                                      02352501
*********************************************************************** 02352701
IEFV21G1 EQU   *                                                   4601 02353013
         L     R5,16                         LOAD CVT ADDR              02360000
         USING CVT,R5                                                   02380000
         L     R5,CVTMSER                    LOAD ADDR OF MASTER        02400000
         DROP  R5                                 CORE FROM CVT         02420000
         USING BASE,R5                                                  02440000
         TM    BASFL,BAJN               DISPLAY JOBNAMES                02460018
*                                                 FLAG                  02480000
         BZ    IEF21GDA                NO, GO CHECK REMOTE USER  X02050 02500002
         GETMAIN R,LV=LN1,SP=240       GET AREA FOR MESSAGE         MCS 02520001
         L     R2,WTOL                 ADDR. OF MSG CSECT          KMSA 02542016
         MVC   0(LN1,R1),0(R2)         SET UP MSG COPY              MCS 02543018
         LR    R2,R1                    SAVE GETMAIN @                  02543501
         USING IEFWSTRT,R1             ADDRESSABILITY TO MESSAGE X02050 02544003
         MVC   USERID(D7),QIDUSRID     PUT USERID IN MESSAGE     X02050 02547003
         BAL   R14,IEF21S2             GET TIME AND ADD TO MSG   X02050 02549003
         TM    MSBTN,MSTN              WAS TIME REQUESTED?       X02050 02551003
         BO    IEF21GA                 IF SO, DO NOT REMOVE      X02050 02553003
         MVC   TIME1(D22),USER         ELSE OVERLAY WITH USERID  X02050 02557003
         MVI   LENGTH1,SHORTLN2        RESET LENGTH VALUE        X02050 02559003
         LH    R11,JOBSQID             GET QID TO CHECK FOR REMT X02050 02561003
         LTR   R11,R11                 IS JOB FROM REMOTE USER?  X02050 02563003
         BNZ   IEF21GD                 IF REMOTE, GO ISSUE WTO   X02050 02567003
         MVC   TIME1(D8),CODES1        ELSE CLEAR USERID IN MSG  X02050 02570003
         MVI   LENGTH1,SHORTLN1        RESET MESSAGE LENGTH      X02050 02573003
         B     IEF21GD                 GO ISSUE MESSAGE          X02050 02577003
IEF21GA  EQU   *                                                 X02050 02580003
         LH    R11,JOBSQID             CHECK QID FOR REMOTE      X02050 02583003
         LTR   R11,R11                 IS JOB FROM REMOTE USER?  X02050 02585003
         BNZ   IEF21GD                 IF SO, ISSUE MESSAGE      X02050 02587003
         MVC   USER(D8),CODES1         ELSE REMOVE USERID        X02050 02589003
         MVI   LENGTH1,SHORTLN2        RESET MESSAGE LENGTH      X02050 02593003
IEF21GD  EQU   *                                                  KMSA  02597016
         MVC   JOBNAME1(8),JCTJNAME     PUT NEW JOBNAME IN BUFFER   MCS 02627018
         WTO   MF=(E,(1))                    WRITE TO OPERATOR          02660000
IEF21GDA EQU   *                                                 X02050 02660102
         LH    R11,JOBSQID             IS THERE A                X02050 02660202
         LTR   R11,R11                   REMOTE USER             X02050 02660402
         BZ    IEF21GG                 NO, GO ISSUE FREEMAIN     X02050 02660602
         TM    QIDIND4,QIDMJOBN        MONITOR JOBNAMES ACTIVE?  X02050 02660802
         BZ    IEF21GG                 NO, GO ISSUE FREEMAIN     X02050 02661002
         TM    BASFL,BAJN              IS DISPLAY JOBNAMES ACTIVEX02050 02661302
         BO    IEF21GB                 YES. GO BUILD MSG IN AREA THAT  *02661602
                                       WAS USED FOR DISP JN MSG  X02050 02661802
         GETMAIN R,LV=LN1,SP=240       NO. GET AREA FOR MSG      X02050 02662002
         LR    R2,R1                    SAVE GETMAIN ADDR      @XA07093 02662204
IEF21GB  EQU   *                                               @XA07093 02662604
         L     R7,WTOL                  ADDR OF MSG CSECT      @XA07093 02662804
         LR    R1,R2                   GET ADDRESS OF MSG TEXT   X02050 02662903
         MVC   0(LN1,R1),0(R7)         INITIALIZE MESSAGE AREA @XA07093 02663004
         STH   R11,QID1                PUT QID IN MESSAGE        X02050 02663103
         MVC   USER(D8),CODES1         ELIMINATE USER PARM       X02050 02663203
         MVI   LENGTH1,SHORTLN2        RESET MESSAGE LENGTH      X02050 02663303
         TM    QIDIND4,QIDMJOBT        IS TIME NOTE WANTED?      X02050 02663403
         BZ    IEF21GE                 IF NOT, ISSUE MESSAGE     X02050 02663503
         BAL   R14,IEF21S2             YES. GO PUT TIME IN MSG   X02050 02663602
         B     IEF21GF                 GO ISSUE WTO              X02050 02663802
IEF21GE  EQU   *                                                 X02050 02664002
         MVI   LENGTH1,SHORTLN1        RESET MSG LENGTH          X02050 02664202
         MVC   TIME1(8),CODES1         ADJUST MSG FOR NO TIME    X02050 02664402
IEF21GF  EQU   *                                                 X02050 02664602
         MVC   JOBNAME1(8),JCTJNAME    PUT JOBNAME IN MSG        X02050 02664802
         WTO   MF=(E,(1))              WRITE MSG TO TERMINAL     X02050 02665202
         B     IEF21GH                 GO ISSUE FREEMAIN         X02050 02665602
IEF21GG  EQU   *                                                 X02050 02666002
         TM    BASFL,BAJN              IS DISPLAY JOBNAMES ACTIVEX02050 02666402
         BZ    IEFV21G                 NO, GO ISSUE ODS          X02050 02666802
IEF21GH  EQU   *                                                 X02050 02667202
         FREEMAIN R,LV=LN1,A=(R2),SP=240  FREE CORE GOTTEN FOR MSG  MCS 02668001
         TITLE  'IEFSD21Q ISSUE SMODS MACRO'                            02676001
*********************************************************************** 02682001
*   ISSUE SPOOL MANAGEMENT OPEN DATA SET MACRO                        * 02688001
*********************************************************************** 02694001
IEFV21G  GETMAIN R,LV=124,SP=252       FOR LRCB+4                       02714001
         LR    R7,R1                   SAVE ADDRESS OF LRCB             02734001
         GETMAIN R,LV=80,SP=240        FOR ODS RPL & PUT RPL            02754001
         LR    R10,R1                  ADDRESS OF ODS RPL               02774001
         XC    0(40,R10),0(R10)        ZERO ODS RPL                     02784001
         USING ODRPL,R10                                                02794001
         MVC   ODRID(4),IDODSRPL       OPEN DS RPL 1ST WORD             02814001
         MVI   ODRRTYP,X'02'           ALLOCATION REQ. TYPE             02834001
         ST    R7,ODRFLAG              INSERT PTR TO LRCB IN RPL        02854001
         ST    R7,LCTLRCB              SAVE PTR TO LRCB IN LCT          02864001
         MVI   ODRFLAG,X'A2'           KEY 0,OUTPUT,WRITE OLD DS        02874001
         L     R3,LCTJSCB              GET JSCB ADDR                    02894001
         USING IEZJSCB,R3                                               02914001
         MVI   ODRDSN,C'S'                                              02934001
         MVI   ODRDSN+1,C'M'                                            02954001
         MVC   ODRDSN+2(4),JSCBID      PUT JOB # INTO NAME FIELD        02974001
         MVI   ODRDSN+6,X'00'          ALWAYS ZERO                      02994001
         MVC   ODRDSN+7(1),JSCBSTEP    PUT STEP # INTO NAME FIELD       03014001
         MVC   ODRDSD(4),DSDTTR        MOVE IN NO DSD TTR INDICATOR     03034001
         ST    R1,120(R7)              SAVE PTR TO RPL AT END OF LRCB   03054001
         NI    LCTALCFG,X'3F'          ZERO ALOC ERROR PASS BACK FLAGS  03074001
         LA    R13,REGSAVE             REG SAVE AREA FOR JES            03094001
         IEFSMREQ                      ISSUE OPEN DS                    03114001
         CLI   ODRFDBK,X'00'           ANY ERRORS FROM OPEN             03120001
         BE    ODSGOOD                 NO,BRANCH                        03126001
         OI    LCTALCFG,LCTODSFL       SET ODS FAILED BIT ON            03132001
ODSGOOD  EQU   *                                                        03138001
         USING RPL,R10                                                  03144001
         XC    0(80,R10),0(R10)        ZERO PUT RPL                     03149001
         MVC   RPLID(4),IDPUTRPL       1ST WORD OF PUT RPL              03154001
         MVC   RPLDACB(3),LCTLRCB+1    PUT LRCB POINTER IN PUT RPL      03174001
         NI    JCTJSTAT,255-JCTSTPFL         TURN OFF STEP FLUSH BIT    03280000
         SPACE 5                                                        03281001
*********************************************************************** 03282001
*        SET UP TO BRANCH TO IEFACTLK                                 * 03283001
*********************************************************************** 03284001
         TM    SCTSSTAT,X'04'           IS THIS STEP DSDRP          JES 03285001
         BO    IEFNOACT                 YES,SKIP ACCT RNT           JES 03286001
         L     R15,IEFACTLK            LOAD VCON                    JES 03288001
ACTRNT   MVC   LRCBPTR(4),LCTLRCB      MOVE IN ADDR OF LRCB INTO        03292001
*                                       PARM LIST                   JES 03293001
         LA    R1,QMPAADD               LOAD ADDR OF PARM LIST IN   JES 03294001
*                                       R1                          JES 03295001
         BALR  R14,R15                 BRANCH TO ACCOUNTING LINK    JES 03297001
*********************************************************************** 03300000
JCTJOBFL EQU   64                            BIT-1/JOB FLUSH BIT-ALLOC* 03320000
JCTSTPFL EQU   16                            BIT-3/STEP FLUSH BIT-ALLC* 03340000
*********************************************************************** 03360000
IEFNOACT EQU   *                                                   CR17 03370017
         TM    JCTJSTAT,INCMSTS              TEST JOB FAILED BIT IN JCT 03380000
         BO    IEFV21P                       BRANCH IF JOB FAILED SET   03400000
         TM    JCTJSTAT,JCTJOBFL             TEST JOB FLUSH             03420000
         BO    IEFV21PV                      BRANCH TO FLUSH EXIT       03440000
         L     R15,IEFV21V2                  LOAD ADDR FOR NORMAL EXIT  03460000
         BR    R15                      *....NORMAL EXIT                03480000
         TITLE  'IEFSD21Q  ERROR EXIT'                                  03490001
*********************************************************************** 03500001
IEFV21P  DS    0H                       *....ERROR EXIT TAKEN BECAUSE   03520000
*                                                 JOB FAILED BIT SET IN 03540000
*                                                 JCT                   03560000
*********************************************************************** 03570001
         NI    JCTJSTAT,255-INCMSTS          TURN OFF JOB FAILED BIT    03580000
         OI    JCTJSTAT,JCTJOBFL             TURN ON JOB FLUSH BIT      03600000
IEFV21PV DS    0H                                                       03620000
         XC    LCTERROR(4),LCTERROR          SET PARAMETER FOR YN-TERM  03640000
         L     R15,IEFV21V3            ADDR OF JFCB HSKP         X02050 03660002
         BR    R15                     EXIT IN FLUSH MODE        X02050 03662002
         EJECT                                                          03664002
*********************************************************************** 03666002
* SUBROUTINE USED TO PUT TIME NOTE IN JOB FAILED MESSAGE         X02050 03668002
*********************************************************************** 03670002
IEF21S1  EQU   *                                                 X02050 03672002
         TIME  DEC                     ISSUE TIME MACRO            KMSA 03680002
         LR    R1,R2                   SAVE @ OF MSG COPY          KMSA 03690002
         SRL   R0,4                    DROP HUNDREDTHS             KMSA 03700002
         USING WTERM040,R1             FOR WTO MSG                 KMSA 03710002
         ST    R0,JOBNAME2             MOVE TIME INTO MSG AREA      MCS 03720002
         OI    JOBNAME2+3,X'0F'        ZONE OUT TENTHS OF SEC       MCS 03730002
         UNPK  JOBNAME2+N2(N6),JOBNAME2(N4)  UNPACK FOR MANUAL   A24159 03740002
*                                            EDIT                A24159 03750002
         MVC   HRS2,JOBNAME2+N2              HOURS               A24159 03760002
         MVI   DOT2A,DOT                     EDIT DOT            A24159 03770002
         MVC   MIN2,JOBNAME2+N4              MINUTES             A24159 03780002
         MVI   DOT2B,DOT                     EDIT DOT            A24159 03790002
         MVC   SEC2,JOBNAME2+N6              SECONDS             A24159 03800002
         MVC   TIME2(L'DTIME),DTIME    REFRESH JOB NOT RUN TIME   M8616 03810002
         MVI   LENGTH2,LONGLEN         LONG MSG LENGTH         @TX67819 03820007
         BR    R14                     RETURN                    X02050 03950002
         SPACE 3                                                        03951002
*********************************************************************** 03952002
* SUBROUTINE USED TO PUT TIME NOTE IN JOB STARTED MSG            X02050 03953002
*********************************************************************** 03954002
IEF21S2  EQU   *                                                 X02050 03955002
         TIME  DEC                     ISSUE TIME MACRO           KMSA  03960002
         SRL   R0,4                    DROP HUNDREDTHS             KMSA 03961002
         LR    R1,R2                   RETURN @ OF MSG COPY TO R1  KMSA 03962002
         USING IEFWSTRT,R1             FOR WTO MSG                 KMSA 03963002
         ST    R0,JOBNAME1             MOVE TIME INTO MSG AREA      MCS 03964002
         OI    JOBNAME1+3,X'0F'         ZONE OUT TENTHS OF SEC      MCS 03965002
         UNPK  JOBNAME1+N2(N6),JOBNAME1(N4)  UNPACK FOR MANUAL   A24159 03966002
*                                            EDIT                A24159 03967002
         MVC   HRS1,JOBNAME1+N2              HOURS               A24159 03968002
         MVI   DOT1A,DOT                     EDIT DOT            A24159 03969002
         MVC   MIN1,JOBNAME1+N4              MINUTES             A24159 03970002
         MVI   DOT1B,DOT                     EDIT DOT            A24159 03971002
         MVC   SEC1,JOBNAME1+N6              SECONDS             A24159 03972002
         MVC   TIME1(L'DTIME),DTIME    REFRESH JOB STARTED TIME   M8616 03973002
         BR    R14                     RETURN                    X02050 03975002
         EJECT                                                          03976002
* CONSTANTS                                                             03977002
IEFACTLK DC    V(IEFACTLK)             ACCOUNTING ROUTINE        X02050 03978002
IEFV21V2 DC    V(IEFVK)                      ALLOCATE-COND CODE ADDR    03980000
IEFV21V3 DC    V(IEFVM1)                     ALLOC FLUSH EXIT -         04000000
*                                                 JFCB HSKP             04020000
WTOL     DC    V(IEFWSTRT)                   WTO JOBNAME MSG ADDR       04060000
WTOAD    DC    V(WTERM040)                                         4601 04070013
SUBPOOL  DC    AL1(240),AL3(0)                                          04075001
VMADC18  DC    V(SWDSFULL)                                              04077001
DTIME    DC    C' TIME='               USED TO REFRESH MSGS       M8616 04241002
SCANRUN  DC    C'TYPRUN=SCAN'          TO BUILD MSG 452I       @TX67819 04241507
N2       EQU   2                                                 A24159 04242018
N4       EQU   4                                                 A24159 04244018
N6       EQU   6                                                 A24159 04246018
DOT      EQU   C'.'      EDIT DOT                                A24159 04248018
         SPACE 2                                                        04248101
*********************************************************************** 04248201
*   PARM LIST FOR ACCOUNTING ROUTINES                                 * 04248301
*********************************************************************** 04248401
QMPAADD  DC    F'0'                     IN CORE ADDR OF QMPA-       JES 04248501
*                                       WILL BE NON-ZERO ONLY WHEN  JES 04248601
*                                       THE CALLING MOD.IS THE      JES 04248701
*                                       OUTPUT WRITER               JES 04248801
DERADD   DC    F'0'                     DER ADDR-ZERO IF NOT IN COREJES 04248901
CALCMPT  DC    X'00000008'              INDICATE INIT(ALLOC.)       JES 04249001
LRCBPTR  DS    F                        PTR TO LRCB                 JES 04249101
*********************************************************************** 04249301
IDODSRPL DC    X'000D710A'             OPEN DS RPL 1ST WORD             04250201
IDPUTRPL DC    X'000D0114'             PUT RPL 1ST WORD                 04251101
DSDTTR   DC    4X'FF'                  NO DSD TTR                       04252001
JOBSQID  DS    H                       QID FOR THIS JOB          X02050 04252502
         EJECT                                                          04253002
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *X02012 04253402
*              SUPERZAP AREA                                     X02012 04253802
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *X02012 04254202
         SPACE 1                                                        04254602
ZAPAREA  DC    13F'-1'                 AREA FOR SUPERZAP'S       X02012 04255002
         EJECT                                                          04255402
IEFWSTRT DSECT                                                          04256018
         DS    0F                                                   MCS 04259018
         DS    X                        UNUSED                      MCS 04262018
LENGTH1  DS    X                        WTO HDR LN                  MCS 04265018
         DS    2X                       MCSFLAG                     MCS 04268018
         DS    8C                       MSG ID                      MCS 04271018
JOBNAME1 DS    8C                       JOBNAME SLOT                MCS 04274018
         DS    8C                       STARTED                     MCS 04277018
TIME1    DS    CL6                     ' TIME='                   M8616 04280002
HRS1     DS    CL2                      HH                       A24159 04281618
DOT1A    DS    CL1                      .                        A24159 04282418
MIN1     DS    CL2                      MM                       A24159 04283218
DOT1B    DS    CL1                      .                        A24159 04284018
SEC1     DS    CL2                      SS                       A24159 04284818
USER     DS    6C                      ' USER='                  X02050 04285203
USERID   DS    8C                      USERID AREA               X02050 04285603
CODES1   DS    2X                       DESC CODE                   MCS 04286018
         DS    2X                       ROUTCDE                     MCS 04289018
         DS    2X                       JOBNAMES                    MCS 04292018
QID1     DS    2X                      QID                       X02050 04293002
LN1      EQU   *-IEFWSTRT               TOTAL BUFFER LN             MCS 04295018
         SPACE 2                                                        04298018
WTERM040 DSECT                                                          04301018
         DS    0F                                                   MCS 04304018
         DS    X                        UNUSED                      MCS 04307018
LENGTH2  DS    X                        WTO HDR LN                  MCS 04310018
         DS    2X                       MCSFLAG                     MCS 04313018
         DS    8C                       MSG ID                      MCS 04316018
JOBNAME2 DS    9C                       JOBNAME SLOT                MCS 04319018
         DS    14C                     CONSTANT MSG TEXT       @TX67819 04322007
REASON   DS    11C                     VARIABLE MSG TEXT       @TX67819 04323007
TIME2    DS    CL6                     ' TIME='                   M8616 04328002
HRS2     DS    CL2                      HH                       A24159 04329618
DOT2A    DS    CL1                      .                        A24159 04330418
MIN2     DS    CL2                      MM                       A24159 04331218
DOT2B    DS    CL1                      .                        A24159 04332018
SEC2     DS    CL2                      SS                       A24159 04332818
CODES2   DS    2X                       DESC CODE                   MCS 04334018
         DS    2X                       ROUTCDE                     MCS 04337018
         DS    2X                       JOBNAMES                    MCS 04340018
QID2     DS    2X                      QID                       X02050 04341002
LN2      EQU   *-WTERM040               TOTAL BUFFER LN             MCS 04343018
         EJECT                                                          04343501
ODRPL    DSECT                                                          04344001
         IEFODRPL                                                       04344501
RPL      DSECT                                                          04345001
         IEFRPL                                                         04345501
         EJECT                                                          04346018
         EJECT                                                          04360000
CVT      DSECT                                                          04380000
         CVT SYS=MFT                                                    04400001
         EJECT                                                          04420000
         IEEBASEA                                                       04440000
         EJECT                                                          04460000
LCT      DSECT                                                          04480000
*********************************************************************** 04500000
*                                                                     * 04520000
*        THE FOLLOWING REPRESENTS A BLOCK OF MAIN STORAGE WHICH IS    * 04540000
*        ALLOCATED FOR THE LIFE OF                                    * 04560000
*        OF THIS INITIATOR.  IT CONTAINS:                             * 04580000
*                                                                     * 04600000
*              (1)  THE LCT (LINKAGE CONTROL TABLE)                   * 04620000
*              (2)  A 2 LEVEL REGISTER SAVE AREA FOLLOWED BY THE      * 04640000
*                   THE QUEUE MANAGER PARAMETER AREA                  * 04660000
*              (3)  AN ALTERNATE QUEUE MANAGER PARAMETER AREA         * 04680000
*                                                                     * 04700000
*********************************************************************** 04720000
  IEFALLCT                                                              04740000
         EJECT                                                          05060000
JCT      DSECT                                                          05080000
         IEFAJCTB                                                       05100000
*  DEFINE "JOB FLUSH" BIT EQUATE IN JCTJSTAT                   @TX67819 05112000
JCTJFLSH EQU   64                      BIT 1 JOB FLUSH BIT     @TX67819 05114000
         EJECT                                                          05120000
SCT      DSECT                                                          05140000
         IEFASCTB                                                       05160000
         EJECT                                                          05165001
CSCB     DSECT                                                          05170001
         IEECHAIN                                                       05175001
         EJECT                                                          05180000
         IEFQMNGR                                                       05190001
         EJECT                                                          05193002
         IEFTCT                                                  A40791 05196002
         EJECT                                                          05199002
         IKJTCB SYS=AOS1                                          M0726 05202002
         EJECT                                                          05217302
         IEEQIDP                                                 X02050 05217802
         EJECT                                                          05218302
         IEEQIDT                                                 X02050 05218802
         EJECT                                                          05219302
         IEZJSCB                                                        05219801
         IEFJESCT                                                       05219901
         END                                                            05220000
++ SRC      (IEFWSTRT) DISTLIB(ASAMPLIB) SYSLIB(SAMPLIB ).
*********************************************************************** 00020000
*                                                                     * 00040000
*                            JOB INITIATION MESSAGE                   * 00060000
*                                                                     * 00080000
*                                                                     * 00100000
* MODULE-NAME = IEFWSTRT (OS/VS1)                              @X048E79 00110004
*                                                              @X048E79 00112004
* DESCRIPTIVE-NAME = JOB INITIATION MESSAGE                    @X048E79 00114004
*                                                              @X048E79 00116004
* COPYRIGHT = NONE                                             @X048E79 00118004
*                                                              @X048E79 00118404
* FUNCTION-----------FORMAT V FOR W T O INTO WHICH IS MOVED           * 00120000
*                    THE JOB NAME FOR JOB BEING INITIATED.            * 00140000
*                                                                     * 00146013
*                   FORMAT V FOR WTO JOB NOT RUN MESSAGE           4601 00152013
*                                                                     * 00160000
* ENTRY POINTS-------IEFWSTRT                                         * 00180000
*                   WTERM040                                       4601 00190013
*                    WTERM050                                      AACA 00195017
*                                                                     * 00200000
* MESSAGES -------- IEF401I JOBNAME STARTED                             00210013
*                   IEF452I JOBNAME JOB NOT RUN - JCL ERROR        4601 00220013
*                                               - TYPRUN=SCAN  @TX67819 00230007
*                                                                     * 00240000
*                                                                     * 00260000
*********************************************************************** 00280000
         ENTRY WTERM040                                            4601 00330013
IEFWSTRT CSECT                    JOB START MESSAGE                     00340000
*D003350,003420-605980                                           X02050 00340602
*A003420-093420                                                  X02050 00341202
         WTO   'IEF403I JJJJJJJJ STARTED TIME=HH.MM.SS USER=        ',D*00342003
               ESC=6,ROUTCDE=2,MSGTYP=JOBNAMES,QID=Y,MF=L      @XA07884 03342004
WTERM040 WTO   'IEF452I JJJJJJJJ JOB NOT RUN -  JCL ERROR  TIME=HH.MM.S*06342007
               S',DESC=6,ROUTCDE=2,MSGTYP=JOBNAMES,QID=Y,MF=L  @TX67819 06392007
         END                                                            06442007
??
//SMPCNTL  DD  *
  RECEIVE S(TX67819)
        .
//*
//APPLYCK EXEC SMP4
//SMPCNTL  DD  *
  APPLY S(TX67819)
        CHECK
        BYPASS(ID)
        .
//*
//APPLY   EXEC SMP4
//SMPCNTL  DD  *
  APPLY S(TX67819)
        .
//

//*---- use the following steps for REJECT or RESTORE ------------- ***
//REJECT  EXEC SMP4
//SMPCNTL  DD  *
  REJECT S(TX67819).
//

//RESTORE EXEC SMP4
//SMPCNTL  DD  *
  RESTORE S(TX67819).
//
